Crate luhnmod10

Crate luhnmod10 

Functions

valid
Validates if number string is luhn valid. Returns true if the number string is luhn valid, and false otherwise. The number passed to the function must contain only numeric characters otherwise behavior is undefined.