Crate luhnmod10
luhnmod10
1.1.0
All Items
Crate Items
Functions
Crate
luhnmod10
Functions

valid
Validates if number string is luhn valid. Returns true if the number string is luhn valid, and false otherwise. The number passed to the function must contain only numeric characters otherwise behavior is undefined.